==> ultraman-bocp-gen-codegen-0.0.17-sources.jar: com/xforceplus/ultraman/bocp/gen/util/BoGenerator.java <==
package com.xforceplus.ultraman.bocp.gen.util;

import com.baomidou.mybatisplus.generator.config.*;
import com.baomidou.mybatisplus.generator.config.rules.NamingStrategy;
import com.xforceplus.ultraman.bocp.gen.config.*;
import com.xforceplus.ultraman.bocp.gen.constant.CodeGenConstant;
import com.xforceplus.ultraman.bocp.gen.generator.BocpAutoGenerator;
import com.xforceplus.ultraman.bocp.gen.po.BoGenField;
import com.xforceplus.ultraman.bocp.gen.po.BoGenInfo;
import com.xforceplus.ultraman.bocp.gen.po.ModuleInfo;

import java.util.ArrayList;
import java.util.List;

/**
 * <p>
 * mysql 代码生成器演示例子
 * </p>
 *
 * @author wangzheng
 * @since 2019-11-19
 */
public class BoGenerator {

    /**
     * RUN THIS
     */
    public static void main(String[] args) {

        // 代码生成器
        BocpAutoGenerator mpg = new BocpAutoGenerator();
        // 全局配置
        GlobalConfig gc = new GlobalConfig();
        gc.setAuthor("wangzheng");
        gc.setBaseResultMap(true);
        gc.setOpen(false);
        mpg.setGlobalConfig(gc);

        // 数据源配置
        DataSourceConfig dsc = new DataSourceConfig();
        dsc.setUrl("jdbc:mysql://120.55.249.44:27306/bocp?useUnicode=true&serverTimezone=GMT&useSSL=false&characterEncoding=utf8");
        // dsc.setSchemaName("public");
        dsc.setDriverName("com.mysql.jdbc.Driver");
        dsc.setUsername("root");
        dsc.setPassword("xplat");
        mpg.setDataSource(dsc);

//        DataSourceConfig dsc = new DataSourceConfig();
//        dsc.setUrl("jdbc:mysql://localhost:3306/pfcp?useUnicode=true&serverTimezone=GMT&useSSL=false&characterEncoding=utf8");
//        // dsc.setSchemaName("public");
//        dsc.setDriverName("com.mysql.jdbc.Driver");
//        dsc.setUsername("root");
//        dsc.setPassword("FGlai123");
//        mpg.setDataSource(dsc);

        // 项目配置
        ProjectConfig prjc = new ProjectConfig();
        prjc.setName("ultraman");
        prjc.setCode("ULTRAMAN");
        prjc.setGroupInfo("com.xforceplus");
        prjc.setRemark("ultraman is a platform");
        prjc.setVersion("0.1.5");
        mpg.setProjectConfig(prjc);

        // 应用配置
        ApplicationConfig appc = new ApplicationConfig();
        appc.setName("ultraman-bocp");
        appc.setAlias("Bocp");
        appc.setCode("BOCP");
        appc.setRemark("Bocp is a low code platform");
        appc.setVersion("0.1.5");
        appc.setUrl("https://xxx.gitlab.com/digital");
        ModuleInfo mdi = new ModuleInfo();
        mdi.setName("ultraman-bocp-metadata");
        mdi.setAlias("Metadata");
        List<ModuleInfo> mdiList = new ArrayList<>();
        mdiList.add(mdi);
        appc.setModuleList(mdiList);
        mpg.setApplicationConfig(appc);

//        appc.setName("ultraman-pfcp");
//        appc.setAlias("Pfcp");
//        appc.setCode("PFCP");
//        appc.setRemark("PFCP is a low code platform");
//        appc.setVersion("0.0.1");
//        appc.setUrl("https://xxx.gitlab.com/digital");
//        ModuleInfo mdi = new ModuleInfo();
//        mdi.setName("ultraman-pfcp-setting");
//        mdi.setAlias("Setting");
//        List<ModuleInfo> mdiList = new ArrayList<>();
//        mdiList.add(mdi);
//        appc.setModuleList(mdiList);
//        mpg.setApplicationConfig(appc);

        //模块配置
        ModuleConfig mdc = new ModuleConfig();
        mdc.setName("ultraman-bocp-metadata");
        mdc.setAlias("Metadata");
        mdc.setCode("METADATA");
        mdc.setModuleType("sys");
        mdc.setVersion("0.1.5");
        mpg.setModuleConfig(mdc);
//        mdc.setName("ultraman-pfcp-setting");
//        mdc.setAlias("Setting");
//        mdc.setCode("SETTING");
//        mdc.setModuleType("sys");
//        mdc.setVersion("0.0.1");
//        mpg.setModuleConfig(mdc);

        // 包配置
        PackageConfig pc = new PackageConfig();
        pc.setModuleName("metadata");
        pc.setParent("com.xforceplus.ultraman.bocp");
        mpg.setPackageInfo(pc);
//        pc.setModuleName("setting");
//        pc.setParent("com.xforceplus.ultraman.pfcp");
//        mpg.setPackageInfo(pc);

        BoConfig bo = new BoConfig();
        List<BoGenInfo> boGenInfos = new ArrayList<>();
        BoGenInfo boGenInfo = new BoGenInfo();
        boGenInfo.setName("coTest");
        boGenInfo.setRemark("Test");
        boGenInfo.setAlias("Botest");
        boGenInfo.setBoType("sys");
        boGenInfo.setCode("BOTEST");
        List<BoGenField> boGenFields = new ArrayList<>();
        BoGenField boGenField = new BoGenField();
        boGenField.setName("id");
        boGenField.setAlias("id");
        boGenField.setFieldKey("1");
        boGenField.setFiledType("varchar");
        boGenField.setRemark("key");
        boGenField.setNullKey("1");
        BoGenField boGenField1 = new BoGenField();
        boGenField1.setName("name");
        boGenField1.setAlias("name");
        boGenField1.setRemark("name");
        boGenField1.setFiledType("varchar");
        boGenFields.add(boGenField);
        boGenFields.add(boGenField1);
        boGenInfo.setBoGenFieldList(boGenFields);
        boGenInfos.add(boGenInfo);
//        bo.setBoInfoList(boInfos);
        bo.setFromDB(true);
        mpg.setBoConfig(bo);

        // 策略配置
        StrategyConfig strategy = new StrategyConfig();
        strategy.setNaming(NamingStrategy.underline_to_camel);
        strategy.setColumnNaming(NamingStrategy.underline_to_camel);
        strategy.setEntityLombokModel(true);
//        strategy.setEntityTableFieldAnnotationEnable(true);
        strategy.setControllerMappingHyphenStyle(true);
        strategy.setTablePrefix(pc.getModuleName() + "_");
        strategy.setSuperMapperClass(CodeGenConstant.SUPER_MAPPER_CLASS);
        NameConvert nameConvert = new NameConvert();
        strategy.setNameConvert(nameConvert);
        mpg.setStrategy(strategy);
        mpg.setEngineType("bo");
        mpg.execute();

        //数据库生成
//        DbScheme dbScheme = new BocpDbScheme();
//        try {
//            dbScheme.initBos(bo,dsc);
//        } catch (Exception e) {
//            e.printStackTrace();
//        }
    }

}

==> ultraman-bocp-gen-codegen-0.0.18-sources.jar: com/xforceplus/ultraman/bocp/gen/util/BoGenerator.java <==
package com.xforceplus.ultraman.bocp.gen.util;

import com.baomidou.mybatisplus.generator.config.*;
import com.baomidou.mybatisplus.generator.config.rules.NamingStrategy;
import com.xforceplus.ultraman.bocp.gen.config.*;
import com.xforceplus.ultraman.bocp.gen.constant.CodeGenConstant;
import com.xforceplus.ultraman.bocp.gen.generator.BocpAutoGenerator;
import com.xforceplus.ultraman.bocp.gen.po.BoGenField;
import com.xforceplus.ultraman.bocp.gen.po.BoGenInfo;
import com.xforceplus.ultraman.bocp.gen.po.ModuleInfo;

import java.util.ArrayList;
import java.util.List;

/**
 * <p>
 * mysql 代码生成器演示例子
 * </p>
 *
 * @author wangzheng
 * @since 2019-11-19
 */
public class BoGenerator {

    /**
     * RUN THIS
     */
    public static void main(String[] args) {
        excuteBOCP();
//        excutePFCP();
    }

    public static void excuteBOCP(){
        // 代码生成器
        BocpAutoGenerator mpg = new BocpAutoGenerator();
        // 全局配置
        GlobalConfig gc = new GlobalConfig();
        gc.setAuthor("wangzheng");
        gc.setBaseResultMap(true);
        gc.setOpen(false);
        mpg.setGlobalConfig(gc);

        // 数据源配置
        DataSourceConfig dsc = new DataSourceConfig();
        dsc.setUrl("jdbc:mysql://120.55.249.44:27306/bocp?useUnicode=true&serverTimezone=GMT&useSSL=false&characterEncoding=utf8");
        // dsc.setSchemaName("public");
        dsc.setDriverName("com.mysql.jdbc.Driver");
        dsc.setUsername("root");
        dsc.setPassword("xplat");
        mpg.setDataSource(dsc);

        // 项目配置
        ProjectConfig prjc = new ProjectConfig();
        prjc.setName("ultraman");
        prjc.setCode("ULTRAMAN");
        prjc.setGroupInfo("com.xforceplus");
        prjc.setRemark("ultraman is a platform");
        prjc.setVersion("0.1.14");
        mpg.setProjectConfig(prjc);

        // 应用配置
        ApplicationConfig appc = new ApplicationConfig();
        appc.setName("ultraman-bocp");
        appc.setAlias("Bocp");
        appc.setCode("BOCP");
        appc.setRemark("Bocp is a low code platform");
        appc.setVersion("0.1.14");
        appc.setUrl("https://xxx.gitlab.com/digital");
        ModuleInfo mdi = new ModuleInfo();
        mdi.setName("ultraman-bocp-metadata");
        mdi.setAlias("Metadata");
        List<ModuleInfo> mdiList = new ArrayList<>();
        mdiList.add(mdi);
        appc.setModuleList(mdiList);
        mpg.setApplicationConfig(appc);

        //模块配置
        ModuleConfig mdc = new ModuleConfig();
        mdc.setName("ultraman-bocp-metadata");
        mdc.setAlias("Metadata");
        mdc.setCode("METADATA");
        mdc.setModuleType("sys");
        mdc.setVersion("0.1.14");
        mpg.setModuleConfig(mdc);

        // 包配置
        PackageConfig pc = new PackageConfig();
        pc.setModuleName("metadata");
        pc.setParent("com.xforceplus.ultraman.bocp");
        mpg.setPackageInfo(pc);

        BoConfig bo = new BoConfig();
        List<BoGenInfo> boGenInfos = new ArrayList<>();
        BoGenInfo boGenInfo = new BoGenInfo();
        boGenInfo.setName("coTest");
        boGenInfo.setRemark("Test");
        boGenInfo.setAlias("Botest");
        boGenInfo.setBoType("sys");
        boGenInfo.setCode("BOTEST");
        List<BoGenField> boGenFields = new ArrayList<>();
        BoGenField boGenField = new BoGenField();
        boGenField.setName("id");
        boGenField.setAlias("id");
        boGenField.setFieldKey("1");
        boGenField.setFiledType("varchar");
        boGenField.setRemark("key");
        boGenField.setNullKey("1");
        BoGenField boGenField1 = new BoGenField();
        boGenField1.setName("name");
        boGenField1.setAlias("name");
        boGenField1.setRemark("name");
        boGenField1.setFiledType("varchar");
        boGenFields.add(boGenField);
        boGenFields.add(boGenField1);
        boGenInfo.setBoGenFieldList(boGenFields);
        boGenInfos.add(boGenInfo);
//        bo.setBoInfoList(boInfos);
        bo.setFromDB(true);
        mpg.setBoConfig(bo);

        // 策略配置
        StrategyConfig strategy = new StrategyConfig();
        strategy.setNaming(NamingStrategy.underline_to_camel);
        strategy.setColumnNaming(NamingStrategy.underline_to_camel);
        strategy.setEntityLombokModel(true);
//        strategy.setEntityTableFieldAnnotationEnable(true);
        strategy.setControllerMappingHyphenStyle(true);
        strategy.setTablePrefix(pc.getModuleName() + "_");
        strategy.setSuperMapperClass(CodeGenConstant.SUPER_MAPPER_CLASS);
        NameConvert nameConvert = new NameConvert();
        strategy.setNameConvert(nameConvert);
        mpg.setStrategy(strategy);
        mpg.setEngineType("bo");
        mpg.execute();

    };
    public static void excutePFCP(){
        // 代码生成器
        BocpAutoGenerator mpg = new BocpAutoGenerator();
        // 全局配置
        GlobalConfig gc = new GlobalConfig();
        gc.setAuthor("wangzheng");
        gc.setBaseResultMap(true);
        gc.setOpen(false);
        mpg.setGlobalConfig(gc);

        // 数据源配置
        DataSourceConfig dsc = new DataSourceConfig();
        dsc.setUrl("jdbc:mysql://120.55.249.44:27306/pfcp?useUnicode=true&serverTimezone=GMT&useSSL=false&characterEncoding=utf8");
        // dsc.setSchemaName("public");
        dsc.setDriverName("com.mysql.jdbc.Driver");
        dsc.setUsername("root");
        dsc.setPassword("xplat");
        mpg.setDataSource(dsc);

        // 项目配置
        ProjectConfig prjc = new ProjectConfig();
        prjc.setName("ultraman");
        prjc.setCode("ULTRAMAN");
        prjc.setGroupInfo("com.xforceplus");
        prjc.setRemark("ultraman is a platform");
        prjc.setVersion("0.1.5");
        mpg.setProjectConfig(prjc);

        // 应用配置
        ApplicationConfig appc = new ApplicationConfig();
        appc.setName("ultraman-pfcp");
        appc.setAlias("Pfcp");
        appc.setCode("PFCP");
        appc.setRemark("PFCP is a low code platform");
        appc.setVersion("0.0.1");
        appc.setUrl("https://xxx.gitlab.com/digital");
        ModuleInfo mdi = new ModuleInfo();
        mdi.setName("ultraman-pfcp-setting");
        mdi.setAlias("Setting");
        List<ModuleInfo> mdiList = new ArrayList<>();
        mdiList.add(mdi);
        appc.setModuleList(mdiList);
        mpg.setApplicationConfig(appc);

        //模块配置
        ModuleConfig mdc = new ModuleConfig();
        mdc.setName("ultraman-pfcp-setting");
        mdc.setAlias("Setting");
        mdc.setCode("SETTING");
        mdc.setModuleType("sys");
        mdc.setVersion("0.0.1");
        mpg.setModuleConfig(mdc);

        // 包配置
        PackageConfig pc = new PackageConfig();
        pc.setModuleName("setting");
        pc.setParent("com.xforceplus.ultraman.pfcp");
        mpg.setPackageInfo(pc);

        BoConfig bo = new BoConfig();
        List<BoGenInfo> boGenInfos = new ArrayList<>();
        BoGenInfo boGenInfo = new BoGenInfo();
        boGenInfo.setName("coTest");
        boGenInfo.setRemark("Test");
        boGenInfo.setAlias("Botest");
        boGenInfo.setBoType("sys");
        boGenInfo.setCode("BOTEST");
        List<BoGenField> boGenFields = new ArrayList<>();
        BoGenField boGenField = new BoGenField();
        boGenField.setName("id");
        boGenField.setAlias("id");
        boGenField.setFieldKey("1");
        boGenField.setFiledType("varchar");
        boGenField.setRemark("key");
        boGenField.setNullKey("1");
        BoGenField boGenField1 = new BoGenField();
        boGenField1.setName("name");
        boGenField1.setAlias("name");
        boGenField1.setRemark("name");
        boGenField1.setFiledType("varchar");
        boGenFields.add(boGenField);
        boGenFields.add(boGenField1);
        boGenInfo.setBoGenFieldList(boGenFields);
        boGenInfos.add(boGenInfo);
//        bo.setBoInfoList(boInfos);
        bo.setFromDB(true);
        mpg.setBoConfig(bo);

        // 策略配置
        StrategyConfig strategy = new StrategyConfig();
        strategy.setNaming(NamingStrategy.underline_to_camel);
        strategy.setColumnNaming(NamingStrategy.underline_to_camel);
        strategy.setEntityLombokModel(true);
//        strategy.setEntityTableFieldAnnotationEnable(true);
        strategy.setControllerMappingHyphenStyle(true);
        strategy.setTablePrefix(pc.getModuleName() + "_");
        strategy.setSuperMapperClass(CodeGenConstant.SUPER_MAPPER_CLASS);
        NameConvert nameConvert = new NameConvert();
        strategy.setNameConvert(nameConvert);
        mpg.setStrategy(strategy);
        mpg.setEngineType("bo");
        mpg.execute();

        //数据库生成
//        DbScheme dbScheme = new BocpDbScheme();
//        try {
//            dbScheme.initBos(bo,dsc);
//        } catch (Exception e) {
//            e.printStackTrace();
//        }
    };

}
